Description Usage Arguments Value Examples
Discover palette
1 2 3 4 5 6 7 | hermitage_palette("parsons_2")
hermitage_palette("hermitage_1")
hermitage_palette("harmony", 5)
hermitage_palette("imari", 5)
hermitage_palette("du_barry", 3)
For more colours:
more_colours <- hermitage_palette(25, name = "imari", type = "continuous")
|
name |
Name of the palette. Options:
|
n |
Number of colours needed. The largest palettes are parsons_1 and parsons_2 inspired by Thomas Parsons's colour samples from the book "A Tint Of Historical colours" (1934) and include 87 colours and 120 colours, respectively. du_barry (n=4), delft_ware (n=4), imari (n=7) palettes and several others are inspired by the book "The anatomy of colour" by Patrick Baty. Other palettes are inspired by art collection of Hermitage museum. |
type |
Either "continuous" or "discrete". |
A vector of colours
1 | hermitage_palette("parsons_1")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.